@@ -62,7 +62,7 @@ class ShapeParser:
         "double": Type.float,
         "float": Type.float,
         "timestamp": ExternalImport(ImportString("datetime"), "datetime"),
-        "blob": TypeSubscript(Type.Union, [Type.bytes, Type.IOBytes]),
+        "blob": TypeSubscript(Type.Union, [Type.bytes, Type.IOBytes, TypeClass(StreamingBody)]),
     }
 
     # Alias map fixes added by botocore for documentation build.
