@@ -1,5 +1,5 @@
 """
-Wrapper for `typing/typing_extensions.Literal` type annotations like `Literal['a', 'b']`
+Wrapper for `typing/typing_extensions.Literal` type annotations like `Literal['a', 'b']`.
 """
 from typing import Any, Iterable
 
@@ -13,7 +13,7 @@ from mypy_boto3_builder.utils.strings import is_reserved
 
 class TypeLiteral(FakeAnnotation):
     """
-    Wrapper for `typing/typing_extensions.Literal` type annotations like `Literal['a', 'b']`
+    Wrapper for `typing/typing_extensions.Literal` type annotations like `Literal['a', 'b']`.
 
     Arguments:
         name -- Literal name for non-inline.
@@ -24,22 +24,29 @@ class TypeLiteral(FakeAnnotation):
     def __init__(self, name: str, children: Iterable[Any]) -> None:
         self.children = set(children)
         self.name = self._find_name(name)
-        if not name:
-            raise ValueError("Literal should have name")
         if not children:
             raise ValueError("Literal should have children")
 
     def get_sort_key(self) -> str:
+        """
+        Sort literals by name.
+        """
         return self.name
 
     @property
     def inline(self) -> bool:
+        """
+        Whether Litereal should be rendered inline.
+
+        1-value literals are rendered inline.
+        """
         return len(self.children) == 1
 
     def _find_name(self, name: str) -> str:
         # FIXME: hack for APIGWv2
         if name == "__stringType":
-            return "".join(sorted(self.children)) + "Type"
+            children_name = "".join(sorted(f"{i[0].upper()}{i[1:]}" for i in self.children))
+            return f"{children_name}Type"
         if is_reserved(name):
             return f"{name}Type"
         return name
@@ -90,10 +97,13 @@ class TypeLiteral(FakeAnnotation):
         return True
 
     def add_child(self, child: FakeAnnotation) -> None:
+        """
+        Disabled method to avoid confusion.
+        """
         raise ValueError("Use add_literal_child function.")
 
     def is_same(self, other: "TypeLiteral") -> bool:
         """
-        Check if literals have the same children
+        Check if literals have the same children.
         """
         return self.children == other.children
